package com.hjy.modlue.news;

import com.hjy.common.annotation.Log;
import com.hjy.common.core.controller.BaseController;
import com.hjy.common.core.domain.AjaxResult;
import com.hjy.common.core.page.TableDataInfo;
import com.hjy.common.enums.BusinessType;
import com.hjy.common.enums.CbNewsType;
import com.hjy.common.enums.WorkFlowServiceEnums;
import com.hjy.module.mapper.news.CbNewsMapper;
import com.hjy.module.service.news.ICbNewsService;
import com.hjy.module.service.portal.ICbSensitiveService;
import com.hjy.module.service.wf.IWfInstActionTaskService;
import com.hjy.module.vo.news.CbNewsVo;
import com.hjy.module.vo.portal.CbSensitiveVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * 网站新闻Controller
 *
 * @author Tellsea
 * @date 2023-08-22
 */
@Api(tags = "网站新闻Controller")
@RestController
@RequestMapping("/news")
@RequiredArgsConstructor(onConstructor_ = @Autowired)
public class CbNewsController extends BaseController {
    private final ICbNewsService cbNewsService;

    private final CbNewsMapper cbNewsMapper;

    private final IWfInstActionTaskService wfInstActionTaskService;

    private final ICbSensitiveService cbSensitiveService;

    @ApiOperation("查询网站新闻列表")
    @PreAuthorize("@ss.hasPermi('business:NEWS:list')")
    @GetMapping("/list")
    public TableDataInfo<CbNewsVo> list(CbNewsVo entity) {
        return cbNewsService.queryList(entity);
    }

    @ApiOperation("获取网站新闻详细信息")
    @PreAuthorize("@ss.hasPermi('business:NEWS:query')")
    @GetMapping(value = "/getInfo/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id) {
        return AjaxResult.success("查询成功", cbNewsService.queryById(id));
    }

    @ApiOperation("新增网站新闻")
    @PreAuthorize("@ss.hasPermi('business:NEWS:add')")
    @Log(title = "网站新闻", businessType = BusinessType.INSERT)
    @PostMapping("add")
    public AjaxResult add(@RequestBody CbNewsVo entity) {
        // 获取敏感集合
        List<CbSensitiveVo> list = cbSensitiveService.queryAll(new CbSensitiveVo());

        for (CbSensitiveVo sensitive : list) {
            // 构建匹配模式，允许分隔符或特殊字符在敏感词中间
            String regex = "\\b" + Pattern.quote(sensitive.getSensitive()) + "\\b";
            Pattern pattern = Pattern.compile(regex, Pattern.CASE_INSENSITIVE);

            Matcher matcher = pattern.matcher(entity.getContent());

            if (matcher.find()) {
                return AjaxResult.error("包含敏感字符，请修改");
            }
        }
        cbNewsService.save(entity);
        if (!CbNewsType.DRAFTS.getCode().equals(entity.getStatus())){
            wfInstActionTaskService.statrWfqueue(WorkFlowServiceEnums.NEWSSERVICE.getService(), entity.getId(), "新闻新增审核");
            return AjaxResult.success("审核发起");
        }
        return AjaxResult.success("保存成功");
    }

    @ApiOperation("修改网站新闻")
    @PreAuthorize("@ss.hasPermi('business:NEWS:edit')")
    @Log(title = "网站新闻", businessType = BusinessType.UPDATE)
    @PostMapping("edit")
    public AjaxResult edit(@RequestBody CbNewsVo entity) {
        return toAjax(cbNewsService.updateById(entity));
    }

    @ApiOperation("新闻置顶接口")
    @PreAuthorize("@ss.hasPermi('business:NEWS:top')")
    @Log(title = "新闻网站",businessType = BusinessType.UPDATE)
    @PostMapping("top")
    public AjaxResult top(String status,String id){
        Integer sum = cbNewsMapper.selectTop();
        if ("6".equals(status) && sum>=6){
            return AjaxResult.error("置顶已经到达上限");
        }
        CbNewsVo cbNewsVo = new CbNewsVo();
        cbNewsVo.setStatus(status);
        cbNewsVo.setId(id);
        return toAjax(cbNewsService.updateById(cbNewsVo));
    }

    @ApiOperation("修改提交审核接口")
    @Log(title = "提交审核",businessType = BusinessType.UPDATE)
    @PostMapping("/audit")
    public AjaxResult audit(@RequestBody CbNewsVo entity){
        boolean s = cbNewsService.updateById(entity);
        System.out.println(s);
        wfInstActionTaskService.statrWfqueue(WorkFlowServiceEnums.NEWSSERVICE.getService(), entity.getId(),"新闻修改审核");
        return AjaxResult.success("审核发起");
    }

}
